// AP(r) Computer Science Marine Biology Simulation:
// The DisplayMap class is copyright(c) 2002 College Entrance
// Examination Board (www.collegeboard.com).
//
// This class is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation.
//
// This class is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

import java.util.HashMap;

/**
 *  AP&reg; Computer Science Marine Biology Simulation:<br>
 *  <code>DisplayMap</code> is a collection that maps environment
 *  object classes to objects that know how to display them.
 *
 *  <p>
 *  The <code>DisplayMap</code> class is
 *  copyright&copy; 2002 College Entrance Examination Board
 *  (www.collegeboard.com).
 *
 *  @author Alyce Brady
 *  @author Jeff Raab, Northeastern University
 *  @version 1 August 2002
 **/
public class DisplayMap
{
    // Class Variables: Not tied to any one DisplayMap object
    private static HashMap map = new HashMap();  // the collection
    private static LocatableDisplay defaultDisplay = new DefaultDisplay();

    /** Associates a display object with an environment object class. If
     *  no class can be found for that name, an error message is printed.
     *  @param envObjClassname the name of a class whose objects might be
     *                      in an <code>Environment</code>
     *  @param displayObj object that knows how to display
     *                      objects of class <code>envObjClassname</code>
     **/
    public static void associate(String envObjClassname,
                                 LocatableDisplay displayObj)
    {
        try 
        {
            // Store the actual class rather than the classname in the map.
            Class envObjClass = Class.forName(envObjClassname);
            map.put(envObjClass, displayObj);
        } 
        catch (ClassNotFoundException e) 
        {
             System.err.println("DisplayMap was unable to find class named " + 
                                    envObjClassname + 
                                    " to associate with display object.\n" +
                                    "Will use default display instead." );
        } 
    }

    /** Finds a display class that knows how to display the given object.
     *  @param obj  the object to display
     **/
    public static LocatableDisplay findDisplayFor(Locatable obj)
    {
        // Go up through the class hierarchy for obj and see
        // if there is a display for its class or superclasses.
        for ( Class c = obj.getClass(); c != Object.class; 
              c = c.getSuperclass() )
        {
            LocatableDisplay display = (LocatableDisplay) map.get(c);
            if ( display != null )
                return display;
        }

        // No specific display found; use default display for generic
        // Locatable object.
        return defaultDisplay;
    }
}
