// AP(r) Computer Science Marine Biology Simulation:
//
// This class is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation.
//
// This class is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

import java.awt.Color;

/** 
 * Class that represents a wall as in a maze
 * walls take up space and objects can't go
 * through them.
 * 
 * @author Barb Ericson
 * Georgia Tech 2005
 */
public class Wall extends AbstractDrawable
{
  // Class Variable: Shared among ALL Walls
  private static int nextAvailableID = 1;   // next avail unique identifier
  
  ///////////// constructors /////////////
  
  /**
   * Constructor that takes an environment and a location
   * @param theEnv  the environment this object is in
   * @param theLoc  the location of this object
   */
  public Wall(Environment theEnv, 
              Location theLoc)
  {
    // call the parent constructor 
    super(nextAvailableID++, theEnv,theLoc);
  }
  
  /**
   * Constructor that takes an environment, location, and 
   * direction
   * @param theEnv  the environment this object is in
   * @param theLoc  the location of this object
   * @param theDir the direction this object is facing
   */
  public Wall(Environment theEnv, 
              Location theLoc, 
              Direction theDir)
  {
    // call the parent constructor
    super(nextAvailableID++, theEnv, theLoc, theDir);
  }
  
  /**
   * Constructor that takes an environment, location, and 
   * direction
   * @param theEnv  the environment this object is in
   * @param theLoc  the location of this object
   * @param theDir the direction this object is facing
   * @param theColor the color to use
   */
  public Wall(Environment theEnv, 
              Location theLoc, 
              Direction theDir,
              Color theColor)
  {
    // call the parent constructor
    super(nextAvailableID++,theEnv,theLoc,theDir,theColor);
  }
  
  /**
   * method to change direction to the new 
   * direction
   * @param newDir the new direction to use
   */
  public void changeDirection(Direction newDir)
  {
    // do nothing (walls don't change direction)
  }
}